@@ -14,8 +14,6 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <stdlib.h>
-
 #include <qrect.h>
 #include <qwidget.h>
 
@@ -35,6 +33,7 @@ const QString& ConfigFile::getFileName() const
 void ConfigFile::restoreGeom(QWidget* widget)
 {
     int x,y,w,h;
+    x = y = w = h = 0;
     getValue(ConfigC::keys[ConfigC::X],x);
     getValue(ConfigC::keys[ConfigC::Y],y);
     getValue(ConfigC::keys[ConfigC::W],w);
@@ -98,6 +97,9 @@ void ConfigFile::setEmuConfig(const emuConfig& inEmuConfig)
     setGroup(ConfigC::groups[ConfigC::Emulation]);
     setEntry(ConfigC::keys[ConfigC::ClockSpeed],myEmuConfig.clockSpeed);
     setEntry(ConfigC::keys[ConfigC::ForceSongSpeed],myEmuConfig.forceSongSpeed);
+#ifdef SID_WITH_SIDPLAY2
+    setEntry(ConfigC::keys[ConfigC::ForceSidModel],myEmuConfig.forceSidModel);
+#endif
     setEntry(ConfigC::keys[ConfigC::MemoryMode],myEmuConfig.memoryMode);
     setEntry(ConfigC::keys[ConfigC::MOS8580],myEmuConfig.mos8580);
     setEntry(ConfigC::keys[ConfigC::MeasuredMasterVolume],myEmuConfig.measuredVolume);
@@ -161,6 +163,9 @@ bool ConfigFile::load()
     setGroup(ConfigC::groups[ConfigC::Emulation]);
     getValue(ConfigC::keys[ConfigC::ClockSpeed],myEmuConfig.clockSpeed);
     getValue(ConfigC::keys[ConfigC::ForceSongSpeed],myEmuConfig.forceSongSpeed);
+#ifdef SID_WITH_SIDPLAY2
+    getValue(ConfigC::keys[ConfigC::ForceSidModel],myEmuConfig.forceSidModel);
+#endif
     getValue(ConfigC::keys[ConfigC::MemoryMode],myEmuConfig.memoryMode);
     getValue(ConfigC::keys[ConfigC::MOS8580],myEmuConfig.mos8580);
     getValue(ConfigC::keys[ConfigC::MeasuredMasterVolume],myEmuConfig.measuredVolume);
@@ -169,7 +174,16 @@ bool ConfigFile::load()
     getValue(ConfigC::keys[ConfigC::FilterFs],myEmuConfig.filterFs);
     getValue(ConfigC::keys[ConfigC::FilterFm],myEmuConfig.filterFm);
     getValue(ConfigC::keys[ConfigC::FilterFt],myEmuConfig.filterFt);
-        
+
+    // Finish emu config.
+    
+    (myAudioConfig.channels == 1) ? (myEmuConfig.channels = SIDEMU_MONO)
+        : (myEmuConfig.channels = SIDEMU_STEREO);
+    (myAudioConfig.precision == 8) ? (myEmuConfig.bitsPerSample = SIDEMU_8BIT)
+        : (myEmuConfig.bitsPerSample = SIDEMU_16BIT);
+    (myAudioConfig.encoding == 0x7f) ? (myEmuConfig.sampleFormat = SIDEMU_SIGNED_PCM)
+        : (myEmuConfig.sampleFormat = SIDEMU_UNSIGNED_PCM);
+
     // HVSC/STIL
              
     setGroup(ConfigC::groups[ConfigC::HVSC_STIL]);
@@ -202,13 +216,6 @@ bool ConfigFile::load()
     getValue(ConfigC::keys[ConfigC::PanPosRightFP],mergedVol);
     myMixerConfig.readMergedPanPosRight(myMixerConfig.volFP,mergedVol);
     
-    (myAudioConfig.channels == 1) ? (myEmuConfig.channels = SIDEMU_MONO)
-        : (myEmuConfig.channels = SIDEMU_STEREO);
-    (myAudioConfig.precision == 8) ? (myEmuConfig.bitsPerSample = SIDEMU_8BIT)
-        : (myEmuConfig.bitsPerSample = SIDEMU_16BIT);
-    (myAudioConfig.encoding == 0x7f) ? (myEmuConfig.sampleFormat = SIDEMU_SIGNED_PCM)
-        : (myEmuConfig.sampleFormat = SIDEMU_UNSIGNED_PCM);
-
     return success;
 }
 
