@@ -21,7 +21,7 @@ class QWidget;
 
 #include <qstring.h>
 
-#include <sidplay/emucfg.h>
+#include "wrapper/emucfg.h"
 
 #include "AudioConfig.h"
 #include "HVSC_Config.h"
