@@ -14,9 +14,8 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <math.h>
-
 #include <qcheckbox.h>
+#include <qlabel.h>
 #include <qpainter.h>
 #include <qpixmap.h>
 #include <qpushbutton.h>
@@ -30,7 +29,6 @@ FilterDialog::FilterDialog(QWidget* parent, const char* name,
                            bool modal, WFlags fl)
 : FilterDialogData(parent,name,modal,fl)
 {
-    setFixedSize(width(),height());
     setIcon(*mainIcon);
 
     enableChangedSignal(true);
@@ -138,15 +136,18 @@ void FilterDialog::paintFilterFunc()
     paintBuf.begin(&myFiltPic);
     QColor myPenColor(0,0,255);  // rgb
     paintBuf.setPen(myPenColor);
+#ifndef SID_WITH_SIDPLAY2
     extern float filterTable[0x800];  // the only way
     for (int i=0; i<0x800; i++)
     {
         paintBuf.drawPoint((int)(i/15.75),(int)(filterTable[i]*100.0));
     }
+#endif
     paintBuf.end();
 
-    QPainter paint(this);
-    paint.drawPixmap(220,0,myFiltPic);
+    bitBlt( FiltPicFrame, 0, 0,
+            &myFiltPic, 0, 0, myFiltPic.width(), myFiltPic.height(),
+            Qt::CopyROP, false );
 }
 
 void FilterDialog::paintEvent(QPaintEvent *)
