@@ -35,14 +35,21 @@ class AudioDriver : public AudioBase
 	// Free and close opened audio device and reset any variables that
 	// reflect the current state of the driver.
 	void close();
+   
+    void unload();
 	
 	void play(void* buffer, unsigned long int bufferSize);
 
 	bool reset();
 	
+    const char* getName() const
+    {
+        return "OSS";
+    }
+   
  private:  // ------------------------------------------------------- private
 
-	static const char AUDIODEVICE[];
+	static const char *AUDIODEVICE[];
 	int audioHd;
 	
 	void outOfOrder();
