@@ -14,12 +14,13 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <iostream.h>
-#include <iomanip.h>
-
-#include <stdio.h>
+#include <iostream>
+#include <iomanip>
+#include <cstdio>
+using namespace std;
 
 #include <qapplication.h>
+#include <qcstring.h>
 #include <qdir.h>
 #include <qdialog.h>
 #include <qfile.h>
@@ -28,11 +29,23 @@
 #include <qstring.h>
 
 #include "AudioConfig.h"
+#include "AudioDrivers.h"
+#include "AudioDriver.h"
+#include "AudioDriverNull.h"
+#ifdef XSID_HAVE_ARTSC
+#include "AudioDriverARTSC.h"
+#endif
+#ifdef XSID_HAVE_ESD
+#include "AudioDriverESD.h"
+#endif
+
 #include "ConfigFile.h"
 #include "ConfigFileOld.h"
 #include "ConfigC.h"
 #include "MainDialog.h"
 #include "Player.h"
+#include "PlaylistItem.h"
+#include "wrapper/EmuWrapper.h"
 
 #include "filenames.h"
 
@@ -54,7 +67,16 @@ int main(int argc, char** argv)
     QApplication a(argc,argv);
 
     // -------------------------------------------------------------- Globals
-    
+
+    AudioDrivers::addDriver( new AudioDriverNull, true );
+    AudioDrivers::addDriver( new AudioDriver );
+#ifdef XSID_HAVE_ESD
+    AudioDrivers::addDriver( new AudioDriverESD );
+#endif
+#ifdef XSID_HAVE_ARTSC
+    AudioDrivers::addDriver( new AudioDriverARTSC );
+#endif
+        
     player = new Player;
     
     // The SIDPLAY taskbar/panel icon.
@@ -93,7 +115,7 @@ int main(int argc, char** argv)
     QString configFileName = configPath + '/' + CONFIG_FILE_NAME;
     config = new ConfigFile(configFileName);
     // The default for those who have no custom emu config yet.
-    config->setEmuConfig( player->getEmuConfigDefault() );
+    config->setEmuConfig( player->getEmuEngine()->getConfigDefault() );
 
     // Upgrade from old config file (if any).
     QString oldConfigFileName = homePath + '/' + OLD_CONFIG_FILE_NAME;  // obsolete
@@ -103,7 +125,7 @@ int main(int argc, char** argv)
         ConfigFileOld* myOldConfigFile = new ConfigFileOld(oldConfigFileName);
         // Somewhat difficult way to retrieve default config from emuEngine
         // to provide defaults when no config file is present.
-        myOldConfigFile->setEmuConfig( player->getEmuConfigDefault() );
+        myOldConfigFile->setEmuConfig( player->getEmuEngine()->getConfigDefault() );
         myOldConfigFile->load();
         // The following converts the old config to new config style.
         // Parameters not set by the old config get set to defaults.
@@ -157,15 +179,20 @@ int main(int argc, char** argv)
             }
             else
             {
-                if (strnicmp(&argv[myArg][1],"-expert",7) == 0)
+                if (qstrnicmp(&argv[myArg][1],"-expert",7) == 0)
                     expertMode = true;
-                else if (strnicmp(&argv[myArg][1],"bufsize",7) == 0)
+                if (qstrnicmp(&argv[myArg][1],"-nosnd",6) == 0)
+                {
+                    config->setGroup( ConfigC::groups[ConfigC::Audio] );
+                    config->setEntry( ConfigC::keys[ConfigC::Driver], "No Sound" );
+                }
+                else if (qstrnicmp(&argv[myArg][1],"bufsize",7) == 0)
                     argLineAC.bufSize = atoi(&argv[myArg][1+7]);
-                else if (strnicmp(&argv[myArg][1],"maxfrags",8) == 0)
+                else if (qstrnicmp(&argv[myArg][1],"maxfrags",8) == 0)
                     argLineAC.maxFrags = atoi(&argv[myArg][1+8]);
-                else if (strnicmp(&argv[myArg][1],"fragsize",8) == 0)
+                else if (qstrnicmp(&argv[myArg][1],"fragsize",8) == 0)
                     argLineAC.fragSize = atoi(&argv[myArg][1+8]);
-                else if (strnicmp(&argv[myArg][1],"o",1) == 0)
+                else if (qstrnicmp(&argv[myArg][1],"o",1) == 0)
                     commandLineStartSong = atoi(&argv[myArg][1+1]);
             }
         }
@@ -186,6 +213,8 @@ int main(int argc, char** argv)
 
     // ----------------------------------------------------------------------
 
+    expertMode = false;  // !!! (ms) 1.6.0 - disabled
+    
     config->setGroup( ConfigC::groups[ConfigC::Misc] );
     config->setEntry( ConfigC::keys[ConfigC::ExpertMode], expertMode );
         
@@ -234,7 +263,8 @@ int main(int argc, char** argv)
 
     if ( inFile!=0 )
     {
-        mainDlg->playFileMain(argv[inFile],commandLineStartSong,true,false);
+        PlaylistItem pi;  // just a dummy
+        mainDlg->playFileMain( argv[inFile], commandLineStartSong, pi, true, false );
     }
 
     a.setMainWidget(mainDlg);
@@ -245,6 +275,9 @@ int main(int argc, char** argv)
     // ------------------------------------------------------------- Clean up
     
     player->writeConfig(config);
+    player->shutdown();
+    
+    delete mainDlg;
     
     delete mainIcon;
     delete config;
